@@ -1,3 +1,5 @@
+import os
+import atexit
 from uuid import uuid4
 from datetime import datetime
 from threading import local
@@ -6,21 +8,27 @@ from scrapekit.config import Config
 from scrapekit.tasks import TaskManager, Task
 from scrapekit.http import make_session
 from scrapekit.logs import make_logger
-from scrapekit.reports import generate_report
+from scrapekit import reporting
 
 
 class Scraper(object):
     """ Scraper application object which handles resource management
     for a variety of related functions. """
 
-    def __init__(self, name, config=None):
+    def __init__(self, name, config=None, report=True):
         self.name = name
         self.id = uuid4()
         self.start_time = datetime.utcnow()
         self.config = Config(self, config)
+        try:
+            os.makedirs(self.config.data_path)
+        except:
+            pass
         self._task_manager = None
         self.task_ctx = local()
         self.log = make_logger(self)
+        if report:
+            atexit.register(self.report)
 
     @property
     def task_manager(self):
@@ -75,7 +83,7 @@ class Scraper(object):
     def report(self):
         """ Generate a static HTML report for the last runs of the
         scraper from its log file. """
-        index_file = generate_report(self)
+        index_file = reporting.generate(self)
         print "Report available at: %s" % index_file
 
     def __repr__(self):
